MCP Tools module
This module previously provided separate tool classes with #[tool_router]. Now, tools are implemented directly in the SshMcpServer via ServerHandler trait.
Available tools:
shell- Execute shell commands on the remote SSH serversudo_shell- Execute shell commands with sudo privilegescheck_process- Check if a process is still running and read its logread- Read UTF-8 text files from the remote SSH serverapply_patch- Create, update, or delete one remote UTF-8 text filesudo_apply_patch- Apply the same exact patch under sudo
See server.rs for the implementation.
Structs
- Apply
Patch Params - Parameters for the apply_patch tool
- Check
Process Params - Parameters for the check_process tool
- Exec
Params - Parameters for the shell tool
- Read
File Params - Sudo
Exec Params - Parameters for the sudo_shell tool
Enums
- Read
File Mode - Parameters for the read tool