MCP Tools module
This module previously provided separate tool classes with #[tool_router]. Now, tools are implemented directly in the SshMcpServer via ServerHandler trait.
Available tools:
exec- Execute shell commands on the remote SSH serversudo-exec- Execute shell commands with sudo privilegescheck-process- Check if a process is still running and read its logread-file- Read UTF-8 text files from the remote SSH serverwrite-file- Atomically overwrite or create a remote filereplace-in-file- Atomically replace text in a remote file
See server.rs for the implementation.
Structs
- Check
Process Params - Parameters for the check-process tool
- Exec
Params - Parameters for the exec tool
- Read
File Params - Replace
InFile Params - Parameters for the replace-in-file tool
- Sudo
Exec Params - Parameters for the sudo-exec tool
- Write
File Params - Parameters for the write-file tool
Enums
- Read
File Mode - Parameters for the read-file tool